@@ -15,11 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+"""This module contains the Amazon DynamoDB Hook"""
+from __future__ import annotations
 
-
-"""This module contains the AWS DynamoDB hook"""
-import warnings
-from typing import Iterable, List, Optional
+from typing import Iterable
 
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
@@ -27,20 +26,22 @@ from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
 class DynamoDBHook(AwsBaseHook):
     """
-    Interact with AWS DynamoDB.
+    Interact with Amazon DynamoDB.
+    Provide thick wrapper around
+    :external+boto3:py:class:`boto3.resource("dynamodb") <DynamoDB.ServiceResource>`.
+
+    :param table_keys: partition key and sort key
+    :param table_name: target DynamoDB table
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
-
-    :param table_keys: partition key and sort key
-    :param table_name: target DynamoDB table
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     def __init__(
-        self, *args, table_keys: Optional[List] = None, table_name: Optional[str] = None, **kwargs
+        self, *args, table_keys: list | None = None, table_name: str | None = None, **kwargs
     ) -> None:
         self.table_keys = table_keys
         self.table_name = table_name
@@ -48,7 +49,16 @@ class DynamoDBHook(AwsBaseHook):
         super().__init__(*args, **kwargs)
 
     def write_batch_data(self, items: Iterable) -> bool:
-        """Write batch items to DynamoDB table with provisioned throughout capacity."""
+        """
+        Write batch items to DynamoDB table with provisioned throughout capacity.
+
+        .. seealso::
+            - :external+boto3:py:meth:`DynamoDB.ServiceResource.Table`
+            - :external+boto3:py:meth:`DynamoDB.Table.batch_writer`
+            - :external+boto3:py:meth:`DynamoDB.Table.put_item`
+
+        :param items: list of DynamoDB items.
+        """
         try:
             table = self.get_conn().Table(self.table_name)
 
@@ -58,19 +68,3 @@ class DynamoDBHook(AwsBaseHook):
             return True
         except Exception as general_error:
             raise AirflowException(f"Failed to insert items in dynamodb, error: {str(general_error)}")
-
-
-class AwsDynamoDBHook(DynamoDBHook):
-    """
-    This class is deprecated.
-    Please use :class:`airflow.providers.amazon.aws.hooks.dynamodb.DynamoDBHook`.
-    """
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "This class is deprecated. "
-            "Please use :class:`airflow.providers.amazon.aws.hooks.dynamodb.DynamoDBHook`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        super().__init__(*args, **kwargs)
