@@ -17,6 +17,7 @@
 from __future__ import annotations
 
 from datetime import datetime, timedelta
+from time import sleep
 from typing import TYPE_CHECKING, cast
 
 from airflow.compat.functools import cached_property
@@ -24,7 +25,7 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.operators.python import ShortCircuitOperator
 from airflow.providers.amazon.aws.hooks.appflow import AppflowHook
-from airflow.providers.amazon.aws.utils import datetime_to_epoch_ms, get_airflow_version
+from airflow.providers.amazon.aws.utils import datetime_to_epoch_ms
 
 if TYPE_CHECKING:
     from mypy_boto3_appflow.type_defs import (
@@ -35,7 +36,6 @@ if TYPE_CHECKING:
 
     from airflow.utils.context import Context
 
-
 SUPPORTED_SOURCES = {"salesforce", "zendesk"}
 MANDATORY_FILTER_DATE_MSG = "The filter_date argument is mandatory for {entity}!"
 NOT_SUPPORTED_SOURCE_MSG = "Source {source} is not supported for {entity}!"
@@ -53,10 +53,13 @@ class AppflowBaseOperator(BaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     ui_color = "#2bccbd"
 
+    UPDATE_PROPAGATION_TIME: int = 15
+
     def __init__(
         self,
         source: str,
@@ -67,6 +70,7 @@ class AppflowBaseOperator(BaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -80,6 +84,7 @@ class AppflowBaseOperator(BaseOperator):
         self.aws_conn_id = aws_conn_id
         self.region = region
         self.flow_update = flow_update
+        self.wait_for_completion = wait_for_completion
 
     @cached_property
     def hook(self) -> AppflowHook:
@@ -93,6 +98,10 @@ class AppflowBaseOperator(BaseOperator):
         self.connector_type = self._get_connector_type()
         if self.flow_update:
             self._update_flow()
+            # while schedule flows will pick up the update right away, on-demand flows might use out of date
+            # info if triggered right after an update, so we need to wait a bit for the DB to be consistent.
+            sleep(AppflowBaseOperator.UPDATE_PROPAGATION_TIME)
+
         self._run_flow(context)
 
     def _get_connector_type(self) -> str:
@@ -106,7 +115,11 @@ class AppflowBaseOperator(BaseOperator):
         self.hook.update_flow_filter(flow_name=self.flow_name, filter_tasks=[], set_trigger_ondemand=True)
 
     def _run_flow(self, context) -> str:
-        execution_id = self.hook.run_flow(flow_name=self.flow_name, poll_interval=self.poll_interval)
+        execution_id = self.hook.run_flow(
+            flow_name=self.flow_name,
+            poll_interval=self.poll_interval,
+            wait_for_completion=self.wait_for_completion,
+        )
         task_instance = context["task_instance"]
         task_instance.xcom_push("execution_id", execution_id)
         return execution_id
@@ -125,6 +138,7 @@ class AppflowRunOperator(AppflowBaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     def __init__(
@@ -134,6 +148,7 @@ class AppflowRunOperator(AppflowBaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         if source not in {"salesforce", "zendesk"}:
@@ -147,6 +162,7 @@ class AppflowRunOperator(AppflowBaseOperator):
             poll_interval=poll_interval,
             aws_conn_id=aws_conn_id,
             region=region,
+            wait_for_completion=wait_for_completion,
             **kwargs,
         )
 
@@ -164,6 +180,7 @@ class AppflowRunFullOperator(AppflowBaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     def __init__(
@@ -173,6 +190,7 @@ class AppflowRunFullOperator(AppflowBaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         if source not in {"salesforce", "zendesk"}:
@@ -186,6 +204,7 @@ class AppflowRunFullOperator(AppflowBaseOperator):
             poll_interval=poll_interval,
             aws_conn_id=aws_conn_id,
             region=region,
+            wait_for_completion=wait_for_completion,
             **kwargs,
         )
 
@@ -205,6 +224,7 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     template_fields = ("filter_date",)
@@ -218,6 +238,7 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         if not filter_date:
@@ -235,6 +256,7 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
             poll_interval=poll_interval,
             aws_conn_id=aws_conn_id,
             region=region,
+            wait_for_completion=wait_for_completion,
             **kwargs,
         )
 
@@ -272,6 +294,7 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     template_fields = ("filter_date",)
@@ -285,6 +308,7 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         if not filter_date:
@@ -300,6 +324,7 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
             poll_interval=poll_interval,
             aws_conn_id=aws_conn_id,
             region=region,
+            wait_for_completion=wait_for_completion,
             **kwargs,
         )
 
@@ -337,6 +362,7 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
     :param poll_interval: how often in seconds to check the query status
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
+    :param wait_for_completion: whether to wait for the run to end to return
     """
 
     template_fields = ("filter_date",)
@@ -350,6 +376,7 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
         poll_interval: int = 20,
         aws_conn_id: str = "aws_default",
         region: str | None = None,
+        wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         if not filter_date:
@@ -365,6 +392,7 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
             poll_interval=poll_interval,
             aws_conn_id=aws_conn_id,
             region=region,
+            wait_for_completion=wait_for_completion,
             **kwargs,
         )
 
@@ -400,7 +428,7 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
 
     :param flow_name: The flow name
     :param appflow_run_task_id: Run task ID from where this operator should extract the execution ID
-    :param ignore_downstream_trigger_rules: Ignore downstream trigger rules (Ignored for Airflow < 2.3)
+    :param ignore_downstream_trigger_rules: Ignore downstream trigger rules
     :param aws_conn_id: aws connection to use
     :param region: aws region to use
     """
@@ -417,19 +445,13 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
         region: str | None = None,
         **kwargs,
     ) -> None:
-        if get_airflow_version() >= (2, 3):
-            kwargs["ignore_downstream_trigger_rules"] = ignore_downstream_trigger_rules
-        else:
-            self.log.warning(
-                "Ignoring argument ignore_downstream_trigger_rules (%s) - Only supported for Airflow >= 2.3",
-                ignore_downstream_trigger_rules,
-            )
         super().__init__(
             python_callable=self._has_new_records_func,
             op_kwargs={
                 "flow_name": flow_name,
                 "appflow_run_task_id": appflow_run_task_id,
             },
+            ignore_downstream_trigger_rules=ignore_downstream_trigger_rules,
             **kwargs,
         )
         self.aws_conn_id = aws_conn_id
